
#ifndef	_M2M_UTILITIES_H
#define _M2M_UTILITIES_H

/* This file provides utility interfaces available to the M2M application. */


/* Log level enumeration */
typedef enum
{
	VERB,	//print also source-file name, line of the instruction and task ID
	INFO, 	//print the message only without any additional info
	WARN,   //like VERB, but adds a "WARNING" at the beginning of the message.
	ERROR,  //like VERB, but adds an "ERROR" at the beginning of the message
	NONE    //Don't print anything

} LOG_LEVEL;


/* Comment the line below to print on the UART. If using USB, change the USB channel according to the project (see M2M_USB_CH enumeration) */
//#define USBLOG USB_CH3

/* PUBLIC functions*/

UINT32 getUptime(void);
int uptimeAsString(UINT32 uptime, char * string);

void setLogLevel(LOG_LEVEL level);
LOG_LEVEL getLogLevel(void);


int waitRegistration(UINT32 timeout);


/* Message formatting function. It will print on UART or USB according with the defined output stream (see #define USBLOG above)*/
/* According to log level, prints additional information */
void LogFormat ( LOG_LEVEL level, const char* file, int line, const CHAR *fmt, ... );


#	define LOG_ERROR(a...)  LogFormat(ERROR, __FILE__, __LINE__, a)
#	define LOG_WARN(a...)   LogFormat(WARN, __FILE__, __LINE__, a)
#   define LOG_INFO(a...)   LogFormat(INFO, NULL, 0,  a)
#	define LOG_VERB(a...)   LogFormat(VERB, __FILE__, __LINE__, a)


/* INTERNAL functions*/

/* Returns the file name from the complete path */
const char* fileTitle(const char* path);

/* Outputs the given data to the UART directly. */
void PrintToUart(const char *message);

/* Outputs the given data to the specified USB channel  directly. */
void USB_Print (M2M_USB_CH ch, const char *message);

#ifdef USBLOG
	#define LogBase(a)	USB_Print(USBLOG, a)
#else
	#define LogBase(a)	PrintToUart(a)
#endif



#endif  /* _M2M_FS_API_H */

